type options = {
	mutable input_filename: string;
	mutable linefeed: string option;
	mutable utf8: bool;
	mutable help: bool};;

let options = {
	input_filename = "";
	linefeed = None;
	utf8 = false;
	help = false};;

let rec loop_args i = (
	if i >= Array.length Sys.argv then () else
	let a = Sys.argv.(i) in
	if a = "-help" || a = "--help" then (
		options.help <- true;
		loop_args (i + 1)
	) else if String.length a >= 11 && String.sub a 0 11 = "--linefeed=" then (
		let c = String.sub a 11 (String.length a - 11) in
		if c = "native" then options.linefeed <- None else
		if c = "cr" then options.linefeed <- Some "\r" else
		if c = "crlf" then options.linefeed <- Some "\r\n" else
		if c = "lf" then options.linefeed <- Some "\n" else
		failwith ("dfm2text: illegal linefeed " ^ c);
		loop_args (i + 1)
	) else if a = "--utf8" then (
		options.utf8 <- true;
		loop_args (i + 1)
	) else if a.[0] = '-' then (
		failwith ("dfm2text: illegal option " ^ a)
	) else (
		options.input_filename <- a;
		loop_args (i + 1)
	)
) in
loop_args 1;;

if options.help then (
	print_string "usage: dfm2text options source_file\n";
	print_string "  --help                       show this message.\n";
	print_string "  --linefeed=native|cr|crlf|lf replace new-line code.\n";
	print_string "  --utf8                       output string as UTF-8.\n";
	exit 0
);;

begin match options.linefeed with
| Some _ -> set_binary_mode_out stdout true;
| None -> ()
end;;

let input = (
	if options.input_filename <> "" then (
		open_in_bin options.input_filename
	) else (
		set_binary_mode_in stdin true;
		stdin
	)
) in
Dfm_text.resource_to_text ?linefeed:options.linefeed ~utf8:options.utf8
	input stdout;
if options.input_filename <> "" then close_in input;;
